MEDIUM: acl: use temp_pattern to store any integer-type information

All ACL fetches which return integer value now store the result into
the temporary pattern struct. All ACL matches which rely on integer
also get their value there.

Note: the pattern data types are not set right now.
diff --git a/src/proto_tcp.c b/src/proto_tcp.c
index caeb539..9331fdc 100644
--- a/src/proto_tcp.c
+++ b/src/proto_tcp.c
@@ -1286,12 +1286,12 @@
 	return 1;
 }
 
 /* set test->i to the connection's source port */
 static int
 acl_fetch_sport(struct proxy *px, struct session *l4, void *l7, int dir,
                 struct acl_expr *expr, struct acl_test *test)
 {
-	if (!(test->i = get_host_port(&l4->si[0].addr.from)))
+	if (!(temp_pattern.data.integer = get_host_port(&l4->si[0].addr.from)))
 		return 0;
 
 	test->flags = 0;
@@ -1350,7 +1350,7 @@
 	return 1;
 }
 
 /* set test->i to the frontend connexion's destination port */
 static int
 acl_fetch_dport(struct proxy *px, struct session *l4, void *l7, int dir,
                 struct acl_expr *expr, struct acl_test *test)
@@ -1358,7 +1358,7 @@
 	if (!(l4->flags & SN_FRT_ADDR_SET))
 		get_frt_addr(l4);
 
-	if (!(test->i = get_host_port(&l4->si[0].addr.to)))
+	if (!(temp_pattern.data.integer = get_host_port(&l4->si[0].addr.to)))
 		return 0;
 
 	test->flags = 0;
@@ -1286,12 +1286,12 @@
 }
 
-/* set test->i to the connection's source port */
+/* set temp integer to the connection's source port */
 static int
 acl_fetch_sport(struct proxy *px, struct session *l4, void *l7, int dir,
@@ -1350,7 +1350,7 @@
 }
 
-/* set test->i to the frontend connexion's destination port */
+/* set temp integer to the frontend connexion's destination port */
 static int
 acl_fetch_dport(struct proxy *px, struct session *l4, void *l7, int dir,